/************************************************************************/
/*		aPCI-P54 Device Driver											*/
/*																		*/
/*			apci54.h	-	Win32 interface definition					*/
/************************************************************************/

#if !defined( APCI54_H )
#define	APCI54_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI54_SUCCESS				0	/* Successfully proccessed */
#define	APCI54_ERR_SYSTEM			1	/* Call GetLastError() */
#define	APCI54_ERR_NO_DEVICE		2	/* No card */
#define	APCI54_ERR_IN_USE			3	/* Device is in use */
#define	APCI54_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI54_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI54_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI54_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI54_ERR_NO_CREATE		8	/* No created device */

/*==========================================*/
/*	aPCI-P54 card's relative port address	*/
/*==========================================*/
#define	APCI54_PORT_A	0
#define	APCI54_PORT_B	1
#define	APCI54_PORT_C	2
#define	APCI54_PORT_D	3
#define	APCI54_PORT_E	4
#define	APCI54_PORT_F	5

/*==================================*/
/*	aPCI-P54 card's I/O directions	*/
/*==================================*/
#define APCI54_DIR_A_OUTPUT		(0 << 0)
#define APCI54_DIR_A_INPUT		(1 << 0)
#define APCI54_DIR_B_OUTPUT		(0 << 1)
#define APCI54_DIR_B_INPUT		(1 << 1)
#define APCI54_DIR_C_OUTPUT		(0 << 2)
#define APCI54_DIR_C_INPUT		(1 << 2)
#define APCI54_DIR_D_OUTPUT		(0 << 3)
#define APCI54_DIR_D_INPUT		(1 << 3)
#define APCI54_DIR_E_OUTPUT		(0 << 4)
#define APCI54_DIR_E_INPUT		(1 << 4)
#define APCI54_DIR_F_OUTPUT		(0 << 5)
#define APCI54_DIR_F_INPUT		(1 << 5)

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI54_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI54_MAX_PORTS	6			/* Maximum number of user ports */

										/* default search */
#define	APCI54_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI54_BOARD_ID			0x9054	/* pci bus device id */
#define	APCI54_VENDOR_ID		0x136c	/* pci bus vendor id */
										/* our device id */
#define	APCI54_DEVICE_ID	( ( DWORD )APCI54_BOARD_ID\
							| ( ( DWORD )APCI54_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI54_MAX_MEM		9			/* number of memory windows */
#define	APCI54_MAX_IO		20			/* number of i/o windows */
#define	APCI54_MAX_IRQ		7			/* number of irqs */
#define	APCI54_MAX_DMA		7			/* number of dmas */

typedef	struct	_APCI54RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI54_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI54_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI54_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI54_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI54_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI54_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI54_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI54_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI54_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI54RESOURCE, *PAPCI54R;

#if !defined( APCI54_DRIVER )
#define	APCI54_API

#if !defined( APCI54_DLL )
	#define APCI54LIB_API	extern __declspec( dllimport )
#else
	#define APCI54LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI54LIB_API BOOL	WINAPI	Apci54GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI54LIB_API BOOL	WINAPI	Apci54Create( PWORD pwLogSlot );
APCI54LIB_API BOOL	WINAPI	Apci54Close( WORD wLogSlot );
APCI54LIB_API BOOL	WINAPI	Apci54GetResource( WORD wLogSlot, PAPCI54R pres );
APCI54LIB_API BOOL	WINAPI	Apci54GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI54LIB_API BOOL	WINAPI	Apci54GetDirections(WORD wLogSlot, PDWORD pdwDirections);
APCI54LIB_API BOOL	WINAPI	Apci54SetDirections(WORD wLogSlot, DWORD dwDirections);
APCI54LIB_API BOOL	WINAPI	Apci54InPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI54LIB_API BOOL	WINAPI	Apci54OutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI54LIB_API DWORD	WINAPI	Apci54GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI54_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI54_H ) */

/**/